#!/bin/bash
#############################################################################
# Purpose : Run single instance Alfresco docker containers
# Author  : Thore P. C. Kragelund, Redpill Linpro
# Date    : 2014-06-13
# Package : alfresco-docker-utils-1.3.3
# Usage   : Run with base container name and optional arguments
#############################################################################

function create_container {
  CMD="docker run --detach=$DETACH --name $PRJ_NAME-$CNT_NAME"
  if [ -n "$PORT_MAPS" ]; then
    for PORT_MAP in $PORT_MAPS; do
      CMD="$CMD --publish $PORT_MAP"
    done
  fi
  if [ -n "$VOL_MAPS" ]; then
    for VOL_MAP in $VOL_MAPS; do
      CMD="$CMD --volume $VOL_MAP"
    done
  fi
  if [ -n "$CNT_CWD" ]; then
    CMD="$CMD --workdir $CNT_CWD"
  fi
  CMD="$CMD $IMG_NAME"
  if [ -n "$IMG_TAG" ]; then
    CMD="$CMD:$IMG_TAG"
  fi
  if [ -n "$CNT_PARMS" ]; then
    CMD="$CMD $CNT_PARMS"
  fi
  echo $CMD
  $CMD
}

function usage_error {
  echo -n "Usage: ${0##*/}"
  echo -n " <project_name>"
  echo -n " <container_name>"
  echo -n " [-p port]"
  echo -n " [-s ssl_port]"
  echo -n " [-j debug_port]"
  echo -n " [-t image_tag]"
  echo -n " [-o run_opts]"
  echo " [-d]"
  exit 2
}

PRJ_NAME="$1"
CNT_NAME="$2"
[ -z "$PRJ_NAME" -o -z "$CNT_NAME" ] && usage_error
shift 2
DETACH="false"
while getopts c:n:p:s:j:t:o:d OPTION; do
  case ${OPTION} in
    p)
      PORT="$OPTARG"
      ;;
    s)
      SSL_PORT="$OPTARG"
      ;;
    j)
      DEBUG_PORT="$OPTARG"
      ;;
    t)
      IMG_TAG="$OPTARG"
      ;;
    o)
      CNT_PARMS="$OPTARG"
      ;;
    d)
      DETACH="true"
      ;;
    \?)
      usage_error
      ;;
  esac
done

ALF_HOME="/opt/alfresco/$PRJ_NAME"
CNT_ALF_HOME="/opt/alfresco"
ALF_DATA="$ALF_HOME/alf_data"
CNT_ALF_DATA="$CNT_ALF_HOME/alf_data"
CATALINA_HOME="/usr/share/tomcat7"
CATALINA_BASE="/var/lib/tomcat7"

case $CNT_NAME in
  'logserver')
    IMG_NAME="tutum/elasticsearch"
    PORT="${PORT:-9200}"
    PORT_MAPS="$PORT:9200"
    create_container
    ;;
  'log-ui')
    IMG_NAME="arcus/kibana"
    PORT="${PORT:-80}"
    PORT_MAPS="$PORT:80"
    create_container
    ;;
  'alf-db')
    IMG_NAME="thok/alfresco-postgres"
    PORT="${PORT:-5432}"
    PORT_MAPS="$PORT:5432"
    create_container
    ;;
  'alf-repo')
    IMG_NAME="thok/alfresco-tomcat"
    PORT="${PORT:-8080}"
    SSL_PORT="${SSL_PORT:-8443}"
    DEBUG_PORT="${DEBUG_PORT:-8000}"
    PORT_MAPS="$PORT:8080 $SSL_PORT:8443"
    [ "$CNT_PARMS" == "debug" ] && PORT_MAPS="$PORT_MAPS $DEBUG_PORT:8000"
    CNT_PARMS="$CNT_PARMS alfresco.war"
    VOL_MAPS="$ALF_HOME/tomcat-repo:$CATALINA_BASE $ALF_DATA:$CNT_ALF_DATA"
    create_container
    ;;
  'alf-share')
    IMG_NAME="thok/alfresco-tomcat"
    PORT="${PORT:-8081}"
    SSL_PORT="${SSL_PORT:-8444}"
    DEBUG_PORT="${DEBUG_PORT:-8001}"
    PORT_MAPS="$PORT:8080 $SSL_PORT:8443"
    [ "$CNT_PARMS" == "debug" ] && PORT_MAPS="$PORT_MAPS $DEBUG_PORT:8000"
    CNT_PARMS="$CNT_PARMS share.war"
    VOL_MAPS="$ALF_HOME/tomcat-share:$CATALINA_BASE"
    create_container
    ;;
  'alf-solr')
    IMG_NAME="thok/alfresco-tomcat"
    PORT="${PORT:-8082}"
    SSL_PORT="${SSL_PORT:-8445}"
    PORT_MAPS="$PORT:8080 $SSL_PORT:8443"
    CNT_PARMS="$CNT_PARMS solr4.war"
    VOL_MAPS="$ALF_HOME/tomcat-solr:$CATALINA_BASE $ALF_DATA:$CNT_ALF_DATA"
    create_container
    ;;
  *)
    echo "Unknown container '$CNT_NAME'. Exiting .."
    exit 1
esac
